clc; clear all; close all

%% This code computes the steady state of the DSGE model
%% This program requires optimization toolbox of matlab. Trial version is free of charge for a month.
%% Structural Parameters (quarterly calibration)
beta=0.99;                    % discount factor
alphaT=0.4;                   % elasticity of tradable production wrt capital
alphaN=0.33;                  % elasticity of non-tradable production wrt capital
delta=0.025;                  % depreciation rate
sigma=2;                      % relative risk aversion
phi=1;                        % inverse of Frisch elasticity (1+phi=omega in paper) omega=2
G=0.13;                        % share of public spending in ss calibrated from Mongolian data
eta=1.44;                     % elasticity of intratemporal substitution btw trad and non-trad goods
D=1;                         % external debt/GDP ratio calibrated from Mongolian data
aT=1;                         % tfp in the trad sector in steady state
O=0.2; 						  % this is mining share (M), M letter concides with in built funciton in dynare
tO=0.2;						  % tO is effective royalty rate calibrated from Mongolian data
gamma=0.58;                    % share of tradables (alpha in paper) calibrated import share long term average
%% Steady State
h=1/3;                       % hours of work
q=1;                         % marginal value of investment (in terms of lambda)  
rk=1/beta-(1-delta);         % rental rate of capital

%% Steady State (numerical computation)
options = optimoptions('fsolve','MaxFunEvals',300000,'MaxIter',30000,'TolFun',1e-15);

x0=[1,4.72,1/6,4.72];                       % Initial guess
x = fsolve(@(xx) find_steady(xx,rk,alphaN,alphaT,D,beta,delta,gamma,eta,G,h,aT,O),x0,options);

pN=x(1);
kN=x(2);
hN=x(3);
kT=x(4);

p=(gamma+(1-gamma)*pN^(1-eta))^(1/(1-eta));
k=kT+kN;
i=delta*k;
hT=h-hN;
yT=aT*kT^alphaT*hT^(1-alphaT);
yN=kN^alphaN*hN^(1-alphaN);
%% Steady state gdp includes mining
gdp=(pN*yN+yT)/(p-O);
%%% steady state external debt stock. Here the gdp is quarterly, that is why we miltiple 4.
d=D*4*p*gdp;
tb=d/p*(1/beta-1);
g=G*gdp;
%% Mining output using Mining share
yO=O*p*gdp;
%%
c=gdp-i-g-tb;
w=(1-alphaT)*yT/(hT*p);

kappaL=w/(h^phi);
lambda=(c-kappaL/(1+phi)*h^(1+phi))^-sigma;  

%% Steady-state values have ss suffix
gss=g;
aTss=aT;
dss=d;
pNss=pN;
kTss=kT;
kNss=kN;
hTss=hT;
hNss=hN;
rzss=1/beta;
%%
yOss=yO;
pss=p;


%% Parameters not affecting the steady state

kappaI=2.48;              % investment adjustment cost. If 0, q is constant
kappaD=0.00148;           % usually calibrated at a small value. If 0, the model has a unit root
rhoaT=0.8;                % T tfp persistence
rhoaN=0.8;                % N tfp persistence
rhog=0.8;                 % public spending persistence
rhop=0.8;                 % foreign interest rate shock persistence
rhoyO=0.8;				  % mining output persistence
rhopO=0.8;   			  % mining price persistence
rhoc=0.8;				  % preference shock persistence


% save parameters to use them in Dynare
save par beta alphaT alphaN delta sigma phi eta gamma gss...
     kTss kNss hTss hNss aTss kappaL dss pNss rzss...
     kappaI kappaD rhoaT rhoaN rhog rhop rhoyO rhopO rhoc pss

